summaryrefslogtreecommitdiffstats
path: root/kmail/headerstrategy.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
commit86d8364ac704bdc8ad2dfcf52307d9626cfac567 (patch)
tree97d3ac2c2f60780d9a1de4f82caac7cb27534501 /kmail/headerstrategy.cpp
parenta9bde819f2b421dcc44741156e75eca4bb5fb4f4 (diff)
downloadtdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.tar.gz
tdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kmail/headerstrategy.cpp')
-rw-r--r--kmail/headerstrategy.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/headerstrategy.cpp b/kmail/headerstrategy.cpp
index 239525d3..4bd06811 100644
--- a/kmail/headerstrategy.cpp
+++ b/kmail/headerstrategy.cpp
@@ -205,7 +205,7 @@ namespace KMail {
CustomHeaderStrategy::CustomHeaderStrategy()
: HeaderStrategy()
{
- KConfigGroup customHeader( KMKernel::config(), "Custom Headers" );
+ TDEConfigGroup customHeader( KMKernel::config(), "Custom Headers" );
if ( customHeader.hasKey( "headers to display" ) ) {
mHeadersToDisplay = customHeader.readListEntry( "headers to display" );
for ( TQStringList::iterator it = mHeadersToDisplay.begin() ; it != mHeadersToDisplay.end() ; ++ it )
@@ -269,7 +269,7 @@ namespace KMail {
if ( lowerType == "brief" ) return brief();
if ( lowerType == "custom" ) return custom();
// don't kdFatal here, b/c the strings are user-provided
// (KConfig), so fail gracefully to the default:
return standard();
}
@@ -269,7 +269,7 @@ namespace KMail {
if ( lowerType == "custom" ) return custom();
// don't kdFatal here, b/c the strings are user-provided
- // (KConfig), so fail gracefully to the default:
+ // (TDEConfig), so fail gracefully to the default:
return standard();
}